<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://kolarix.com/biztime
 * @since             1.0.0
 * @package           BizTime
 *
 * @wordpress-plugin
 * Plugin Name:       BizTime
 * Plugin URI:        https://kolarix.com/biztime
 * Description:       The plugin shows available times and displays different messages depending on availability.
 * Version:           1.0.0
 * Author:            Kolarix
 * Author URI:        https://kolarix.com/biztime
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       biztime
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'BIZTIME_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-biztime-activator.php
 */
function activate_biztime() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-biztime-activator.php';
	Biztime_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-biztime-deactivator.php
 */
function deactivate_biztime() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-biztime-deactivator.php';
	Biztime_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_biztime' );
register_deactivation_hook( __FILE__, 'deactivate_biztime' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-biztime.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_biztime() {

	$plugin = new Biztime();
	$plugin->run();

}
run_biztime();
